searchData={"items":[{"type":"module","title":"ReqTelemetry","doc":"[`Req`](https://hexdocs.pm/req) plugin to instrument requests with `:telemetry` events.","ref":"ReqTelemetry.html"},{"type":"module","title":"Usage - ReqTelemetry","doc":"Preferably, `ReqTelemetry` should be the last plugin attached to your `%Req.Request{}`. This\nallows `ReqTelemetry` to emit events both at the very start and very end of the request and\nresponse pipelines. In this way, you can observe both the total time spent issuing and\nprocessing the request and response, as well as the time spent only with the request adapter.\n\n    req = Req.new() |> ReqTelemetry.attach()\n\n    req =\n      Req.new(adapter: &my_adapter/1)\n      |> ReqSomeOtherThing.attach()\n      |> ReqTelemetry.attach()","ref":"ReqTelemetry.html#module-usage"},{"type":"module","title":"Events - ReqTelemetry","doc":"`ReqTelemetry` produces the following events (in order of event dispatch):\n\n  * `[:req, :request, :pipeline, :start]`\n  * `[:req, :request, :adapter, :start]`\n  * `[:req, :request, :adapter, :stop]`\n  * `[:req, :request, :adapter, :error]`\n  * `[:req, :request, :pipeline, :stop]`\n  * `[:req, :request, :pipeline, :error]`\n\nYou can configure `ReqTelemetry` to produce only `:pipeline` or `:adapter` events; see\n`ReqTelemetry.attach/2` for options.","ref":"ReqTelemetry.html#module-events"},{"type":"module","title":"Logging - ReqTelemetry","doc":"`ReqTelemetry` defines a a simple, default logger that logs basic request information and timing.\n\nHere's how a successful request might be logged:\n\n    Req:479128347 - GET https://example.org (pipeline)\n    Req:479128347 - GET https://example.org (adapter)\n    Req:479128347 - 200 in 403ms (adapter)\n    Req:479128347 - 200 in 413ms (pipeline)\n\nFor usage and configuration, see `ReqTelemetry.attach_default_logger/1`.","ref":"ReqTelemetry.html#module-logging"},{"type":"function","title":"ReqTelemetry.attach/2","doc":"Installs request, response, and error steps that emit `:telemetry` events.","ref":"ReqTelemetry.html#attach/2"},{"type":"function","title":"Options - ReqTelemetry.attach/2","doc":"* `:pipeline` (default `true`) - emit pipeline telemetry events\n  * `:adapter` (default `true`) - emit adapter telemetry events\n  * `:metadata` (default `nil`) - map of user-supplied metadata available in telemetry handlers\n\nAs a shortcut, all events can be suppressed by passing `false` instead of an options list.\n\nThese same options can also be passed through `Req` options under the `:telemetry` key to\nchange the behavior on a per-request basis. Maps of metadata will be merged. For example:\n\n    req = Req.new() |> ReqTelemetry.attach(metadata: %{api_version: 1})\n\n    Req.get!(req,\n      url: \"https://api.example.org/endpoint\",\n      telemetry: [metadata: %{endpoint: \"endpoint\"}]\n    )\n\n    # Your telemetry event handler will have access to the merged map\n    def handle_event(\n      [:req, _, _, _],\n      _measurements,\n      %{metadata: %{api_version: v, endpoint: e}},\n      _config\n    ) do\n      # ...\n    end","ref":"ReqTelemetry.html#attach/2-options"},{"type":"function","title":"Examples - ReqTelemetry.attach/2","doc":"Emit all events by default, limiting them per-request as needed.\n\n    req = Req.new() |> ReqTelemetry.attach()\n\n    # Emits all events\n    Req.get!(req, url: \"https://example.org\")\n\n    # Do not emit events\n    Req.get!(req, url: \"https://example.org\", telemetry: false)\n\n    # Emit adapter events but not pipeline events\n    Req.get!(req, url: \"https://example.org\", telemetry: [pipeline: false])\n\nSuppress all events by default, enabling them per-request as needed.\n\n    req = Req.new() |> ReqTelemetry.attach(false)\n\n    # Will not emit events\n    Req.get!(req, url: \"https://example.org\")\n\n    # Override to emit events\n    Req.get!(req, url: \"https://example.org\", telemetry: true)\n\n    # Override to emit only adapter events\n    Req.get!(req, url: \"https://example.org\", telemetry: [adapter: true])\n\nFinally, suppress only a certain kind of event by default, overriding that default as needed.\n\n    req = Req.new() |> ReqTelemetry.attach(pipeline: false)\n\n    # Will only emit adapter events\n    Req.get!(req, url: \"https://example.org\")\n\n    # Override to emit only pipeline events\n    Req.get!(req, url: \"https://example.org\", telemetry: [pipeline: true, adapter: false])","ref":"ReqTelemetry.html#attach/2-examples"},{"type":"function","title":"ReqTelemetry.attach_default_logger/1","doc":"Attach a basic telemetry event handler that logs `ReqTelemetry` events.","ref":"ReqTelemetry.html#attach_default_logger/1"},{"type":"function","title":"Usage - ReqTelemetry.attach_default_logger/1","doc":"Telemetry event handlers can be attached in your application's `start/2` callback:\n\n    @impl true\n    def start(_type, _args) do\n      ReqTelemetry.attach_default_logger()\n\n      children = [\n        ...\n      ]\n\n      Supervisor.start_link(...)\n    end\n\nAll events are logged by default, but this can be overriden by passing in a keyword describing\nthe kind of events to log or a list of specific events to log.\n\n    # Logs all events\n    :ok = ReqTelemetry.attach_default_logger()\n\n    # Logs only adapter events\n    :ok = ReqTelemetry.attach_default_logger(:adapter)\n\n    # Logs only pipeline errors\n    :ok = ReqTelemetry.attach_default_logger([[:req, :request, :pipeline, :error]])","ref":"ReqTelemetry.html#attach_default_logger/1-usage"},{"type":"function","title":"Example - ReqTelemetry.attach_default_logger/1","doc":"Here's what a successful request might look like:\n\n    15:52:01.462 [info] Req:479128347 - GET https://example.org (pipeline)\n    15:52:01.466 [info] Req:479128347 - GET https://example.org (adapter)\n    15:52:01.869 [info] Req:479128347 - 200 in 403ms (adapter)\n    15:52:01.875 [info] Req:479128347 - 200 in 413ms (pipeline)\n\nAnd here's what an error might look like:\n\n    15:52:04.174 [error] Req:42446822 - ERROR in 2012ms (adapter)\n    %Finch.Error{reason: :request_timeout}","ref":"ReqTelemetry.html#attach_default_logger/1-example"},{"type":"function","title":"ReqTelemetry.events/1","doc":"Returns a list of events emitted by `ReqTelemetry`.","ref":"ReqTelemetry.html#events/1"},{"type":"type","title":"ReqTelemetry.option/0","doc":"","ref":"ReqTelemetry.html#t:option/0"},{"type":"type","title":"ReqTelemetry.options/0","doc":"","ref":"ReqTelemetry.html#t:options/0"},{"type":"extras","title":"Overview","doc":"[![Hex.pm](https://img.shields.io/hexpm/v/req_telemetry)](https://hex.pm/packages/req_telemetry)\n[![HexDocs.pm](https://img.shields.io/badge/hex.pm-docs-8e7ce6.svg)](https://hexdocs.pm/req_telemetry)\n[![CI](https://github.com/zachallaun/protean/actions/workflows/ci.yml/badge.svg)](https://github.com/zachallaun/req_telemetry/actions/workflows/ci.yml)\n\n<!-- MDOC !-->\n\n[`Req`](https://hexdocs.pm/req) plugin to instrument requests with `:telemetry` events.","ref":"readme.html"},{"type":"extras","title":"Usage - Overview","doc":"Preferably, `ReqTelemetry` should be the last plugin attached to your `%Req.Request{}`. This\nallows `ReqTelemetry` to emit events both at the very start and very end of the request and\nresponse pipelines. In this way, you can observe both the total time spent issuing and\nprocessing the request and response, as well as the time spent only with the request adapter.\n\n    req = Req.new() |> ReqTelemetry.attach()\n\n    req =\n      Req.new(adapter: &my_adapter/1)\n      |> ReqSomeOtherThing.attach()\n      |> ReqTelemetry.attach()","ref":"readme.html#usage"},{"type":"extras","title":"Events - Overview","doc":"`ReqTelemetry` produces the following events (in order of event dispatch):\n\n  * `[:req, :request, :pipeline, :start]`\n  * `[:req, :request, :adapter, :start]`\n  * `[:req, :request, :adapter, :stop]`\n  * `[:req, :request, :adapter, :error]`\n  * `[:req, :request, :pipeline, :stop]`\n  * `[:req, :request, :pipeline, :error]`\n\nYou can configure `ReqTelemetry` to produce only `:pipeline` or `:adapter` events; see\n`ReqTelemetry.attach/2` for options.","ref":"readme.html#events"},{"type":"extras","title":"Logging - Overview","doc":"`ReqTelemetry` defines a a simple, default logger that logs basic request information and timing.\n\nHere's how a successful request might be logged:\n\n    Req:479128347 - GET https://example.org (pipeline)\n    Req:479128347 - GET https://example.org (adapter)\n    Req:479128347 - 200 in 403ms (adapter)\n    Req:479128347 - 200 in 413ms (pipeline)\n\nFor usage and configuration, see `ReqTelemetry.attach_default_logger/1`.\n\n<!-- MDOC !-->","ref":"readme.html#logging"},{"type":"extras","title":"Installation - Overview","doc":"`req_telemetry` is available through [hex.pm](https://hex.pm/packages/req_telemetry), and can be\ninstalled by adding the following to your list of dependencies:\n\n```elixir\ndef deps do\n  [\n    {:req_telemetry, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nThis format is based on [Keep a Changelog](https://keepachangelog.com) and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v0.1.0 (2024-7-9) - Changelog","doc":"#","ref":"changelog.html#v0-1-0-2024-7-9"},{"type":"extras","title":"Added - Changelog","doc":"* Add support for `req` 0.5.X ([#6](https://github.com/zachallaun/req_telemetry/pull/6), thanks @nicholasbair!)\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"* **Breaking:** `req_telemetry` now requires Elixir 1.13+.","ref":"changelog.html#changed"},{"type":"extras","title":"v0.0.4 (2024-1-29) - Changelog","doc":"#","ref":"changelog.html#v0-0-4-2024-1-29"},{"type":"extras","title":"Added - Changelog","doc":"* Add support for `req` 0.4.X ([#5](https://github.com/zachallaun/req_telemetry/pull/5), thanks @aselder!)","ref":"changelog.html#added"}],"content_type":"text/markdown"}